# Feast MySQL Support

This repo adds MySQL offline stores to [Feast](https://github.com/feast-dev/feast)

## Get started

### Install feast:

```shell
pip install feast
```

### Install feast-mysql:

```shell
pip install feast-mysql
```
